BatchSize enum

Defines the Atatus SDK policy when batching data together before uploading it to Atatus servers. Smaller batches mean smaller but more network requests, whereas larger batches mean fewer but larger network requests.

Inheritance
Available extensions

Values

small → const BatchSize

Prefer small sized data batches.

medium → const BatchSize

Prefer medium sized data batches.

large → const BatchSize

Prefer large sized data batches.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BatchSize>
A constant List of the values in this enum, in order of their declaration.