AtatusSdkWeb class

A web implementation of the AtatusSdk plugin.

Inheritance

Constructors

AtatusSdkWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAccountExtraInfo(Map<String, Object?> extraInfo) Future<void>
override
addUserExtraInfo(Map<String, Object?> extraInfo) Future<void>
override
attachToExisting(AtatusAttachConfiguration attachConfig) Future<AttachResponse?>
override
attachToIsolate() Future<IsolateAttachResponse?>
override
checkAgentHeartbeat(AtatusConfiguration configuration, {required InternalLogger internalLogger}) Future<bool>
Checks whether the agent is authorized to transmit data.
inherited
clearAccountInfo() Future<void>
override
clearAllData() Future<void>
override
clearUserInfo() Future<void>
override
flushAndDeinitialize() Future<void>
override
getContext() AtatusContext?
override
initialize(AtatusConfiguration configuration, TrackingConsent trackingConsent, {LogCallback? logCallback, required InternalLogger internalLogger}) Future<PlatformInitializationResult>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTelemetryDebug(String message) Future<void>
override
sendTelemetryError(String message, String? stack, String? kind) Future<void>
override
setAccountInfo(String id, String? name, Map<String, Object?> extraInfo) Future<void>
override
setSdkVerbosity(CoreLoggerLevel verbosity) Future<void>
override
setTrackingConsent(TrackingConsent trackingConsent) Future<void>
override
setUserInfo(String id, String? name, String? email, Map<String, dynamic> extraInfo) Future<void>
override
toString() String
A string representation of this object.
inherited
updateTelemetryConfiguration(String property, bool value) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void