checkAgentHeartbeat method
Future<bool>
checkAgentHeartbeat(
- AtatusConfiguration configuration, {
- required InternalLogger internalLogger,
Checks whether the agent is authorized to transmit data.
Returns true if data collection is allowed, false to suppress it.
The default implementation always returns true, meaning platforms that
do not override this method (e.g. web, desktop) will always be considered
authorized. Platform-specific implementations (Android/iOS) should override
this to perform the actual heartbeat authorization request.
Implementation
Future<bool> checkAgentHeartbeat(
AtatusConfiguration configuration, {
required InternalLogger internalLogger,
}) {
return Future.value(true);
}