sendToAtatus method

void sendToAtatus(
  1. String message,
  2. StackTrace? stack,
  3. String? kind
)

Send a log to the Atatus org, not to the customer's org. This feature is used mostly to track potential issues in the Atatus SDK. The rate at which data is sent to Atatus is set by AtatusRumConfiguration.telemetrySampleRate

Implementation

// ATCHG - Change class name from DDRum to AtatusRum
/// data is sent to Atatus is set by [AtatusRumConfiguration.telemetrySampleRate]
void sendToAtatus(String message, StackTrace? stack, String? kind) {
  // ATCHG - Change class name from DDSdk to AtatusSdk
  AtatusSdkPlatform.instance
      .sendTelemetryError(message, stack?.toString(), kind);
}