atatus_flutter_plugin library
Classes
- AtatusAttachConfiguration
- Configuration options used when attaching to an existing instance of a AtatusSdk.
- AtatusConfiguration
- AtatusLogger
- An interface for sending logs to Atatus.
- AtatusLoggerConfiguration
- Configuration options for a Atatus Log. These options are set for an individual AtatusLogger object
- AtatusLogging
- AtatusLoggingConfiguration
- Configuration options for the Atatus Logging feature. These options are common to all Atatus logs
- This class can be added to a MaterialApp to automatically start and stop RUM views, provided you are using named routes with methods like Navigator.pushNamed, or supplying route names through RouteSettings when using Navigator.push.
- Provides the AtatusNavigationObserver to other classes that need it. Specifically, if you want to use the AtatusRouteAwareMixin, you must use this provider.
- AtatusPlugin
- AtatusPluginConfiguration
- AtatusRum
- AtatusRumConfiguration
- Configuration options for the Atatus Real User Monitoring (RUM) feature.
- AtatusSdk
- A singleton for the Atatus SDK.
- LogDevice
- LogEvent
- LogEventDd
- LogEventError
- LogEventLoggerInfo
- LogEventUserInfo
- RumAction
- RumActionEvent
- RumActionFrustration
- RumActionId
- RumActionTarget
- RumApplication
- RumCellular
- RumConnectivity
- RumContainerView
- RumCount
- RumDevice
- RumError
- RumErrorCause
- RumErrorEvent
- RumGestureDetectorInfo
- Contains information about a gesture-detectable element.
- RumLongTask
- RumLongTaskEvent
- RumOperatingSystem
- RumPerformanceMetric
- RumResource
- RumResourceEvent
- RumResourceSummary
- RumSession
- RumUser
- RumUserActionAnnotation
- Provide information on the user actions that can happen in this tree
- RumUserActionDetector
- Detect simple user actions and send them to RUM.
- RumViewDetails
- RumViewEvent
- RumViewEventDd
- RumViewInfo
- Information about a View that will be passed to AtatusRum.startView
- RumViewSummary
- RumVital
- RumVitalOperationStepContainer
- RumVitalOperationStepEvent
- TracingId
- TracingId is used as both a unsigned 64-bit "Span Id" and unsigned 128-bit "Trace Id"
Enums
- AtatusSite
- Determines the server for uploading RUM events.
- BatchProcessingLevel
- Defines the maximum amount of batches processed sequentially without a delay within one reading/uploading cycle. high means that more data will be sent in a single upload cycle but more CPU and memory will be used to process the data. low means that less data will be sent in a single upload cycle but less CPU and memory will be used to process the data.
- BatchSize
- Defines the Atatus SDK policy when batching data together before uploading it to Atatus servers. Smaller batches mean smaller but more network requests, whereas larger batches mean fewer but larger network requests.
- CoreLoggerLevel
- LogLevel
- Log levels defined by Atatus. Note that not all levels are supported by the Flutter SDK currently, although any level can be used for AtatusLoggerConfiguration.remoteLogThreshold.
- LogStatus
- RumActionType
- Describes the type of a RUM Action.
- RumActionTypeInternal
- RumConnectivityInterfaces
- RumConnectivityStatus
- RumDeviceType
- RumErrorHandling
- RumErrorSource
- Describe the source of a RUM Error.
- RumFeatureOperationFailureReason
- Represents the possible reasons for a failed feature operation.
- RumFrustrationType
- RumHttpMethod
- HTTP method of the resource
- RumInternalErrorSource
- Error sources that include source used internally by Atatus SDKs
- RumResourceType
- Describe the type of resource loaded.
- TraceContextInjection
- Defines whether the trace context should be injected into all requests or only into requests that are sampled in.
- TracingHeaderType
- The type of tracing header to inject into first party requests.
- TracingIdRepresentation
- Controls how we print a TracingId
- TrackingConsent
- Possible values for the Data Tracking Consent given by the user of the app.
- UploadFrequency
- Defines the frequency at which Atatus SDK will try to upload data batches.
- VitalsFrequency
- Defines the frequency at which Atatus SDK will collect mobile vitals, such as CPU and memory usage.
- WebSessionPersistence
- Which storage strategy to use when persisting sessions on Web.
Mixins
-
AtatusRouteAwareMixin<
T extends StatefulWidget> - The AtatusRouteAwareMixin can be used to supply names and additional attributes to RUM views as an alternative to supplying a ViewInfoExtractor to [AtatusNavigationObserver using named routes.
Functions
-
defaultViewInfoExtractor(
Route route) → RumViewInfo? -
The function that provides the default route naming behavior for
[AtatusNavigationObserver
a name, it returns a RumViewInfo with the supplied name. Otherwise it returns
null. -
resourceTypeFromContentType(
ContentType? type) → RumResourceType -
rumMethodFromMethodString(
String value) → RumHttpMethod -
simpleConsolePrint(
LogLevel level, String message, String? errorMessage, String? errorKind, StackTrace? stackTrace, Map< String, Object?> attributes) → void -
Print all logs to the console in the form "
levelmessage" when kDebugMode is true. -
simpleConsolePrintForLevel(
LogLevel level) → CustomConsoleLogFunction -
Print all logs to the console above the given level in the form
"
levelmessage" when kDebugMode is true.
Typedefs
- AppRunner = void Function()
-
CustomConsoleLogFunction
= void Function(LogLevel level, String message, String? errorMessage, String? errorKind, StackTrace? stackTrace, Map<
String, Object?> attributes) -
A function that allows you control Atatus's console log output. This function
is called instead of calling Flutter's default
print, and does not effect what is sent to Atatus. - CustomGestureElementDetector = RumGestureDetectorInfo? Function(Widget widget)
-
This function type allows you to define custom criteria for gesture detection
within your widget tree. It accepts a
Widgetas input and returns aRumGestureDetectorInfoif the widget meets the specified criteria, ornullotherwise. - LogEventMapper = LogEvent? Function(LogEvent event)
- A function that allows you to modify or drop specific LogEvents before they are sent to Atatus.
- RumActionEventMapper = RumActionEvent? Function(RumActionEvent event)
- A function that allows you to modify or drop specific RumActionEvents before they are sent to Atatus.
- RumErrorEventMapper = RumErrorEvent? Function(RumErrorEvent event)
- A function that allows you to modify or drop specific RumErrorEvents before they are sent to Atatus.
- RumLongTaskEventMapper = RumLongTaskEvent? Function(RumLongTaskEvent event)
- A function that allows you to modify or drop specific RumLongTaskEvents before they are sent to Atatus.
- RumResourceEventMapper = RumResourceEvent? Function(RumResourceEvent event)
- A function that allows you to modify or drop specific RumResourceEvents before they are sent to Atatus.
- RumViewEventMapper = RumViewEvent Function(RumViewEvent event)
- A function that allows you to modify specific RumViewEvents before they are sent to Atatus.
- RumVitalOperationEventMapper = RumVitalOperationStepEvent? Function(RumVitalOperationStepEvent event)
-
A function that allows you to modify or drop specific
RumVitalOperationEvents before they are sent to Atatus. - ViewInfoExtractor = RumViewInfo? Function(Route route)
- A function that can be used to supply custom information to AtatusRum.startView.