parentSpanID constant
String
const parentSpanID
Parent Span ID. Used in RUM resources created by automatic resource
tracking when the request is a child of a span created elsewhere
(e.g. a manually started Flutter span). Expects String value
(decimal-encoded 64-bit unsigned span id).
Note: the native Atatus Android SDK does not currently lift this key
into the _atatus block of the resource event automatically, so it
will be uploaded under context._atatus.parent_span_id until the
native SDK adds explicit support.
Implementation
static const parentSpanID = '_atatus.parent_span_id';